import defu from 'defu';
import { resolve } from 'pathe';
import { defineNuxtModule, addPlugin } from '@nuxt/kit';

const module = defineNuxtModule({
  meta: {
    name: "@nuxtjs/strapi",
    compatibility: { nuxt: "^3.0.0" },
    configKey: "strapi"
  },
  defaults: {
    url: "http://localhost:1337",
    prefix: "/api",
    version: "v4"
  },
  setup(_options, nuxt) {
    const strapiConfig = nuxt.options.publicRuntimeConfig.strapi = defu({ url: process.env.STRAPI_URL }, _options);
    if (!strapiConfig.url) {
      throw new Error("Missing `STRAPI_URL` in `.env`");
    }
    addPlugin(resolve(__dirname, "./plugins/strapi"));
    nuxt.hook("autoImports:dirs", (dirs) => {
      dirs.push(resolve(__dirname, "./composables"));
    });
  }
});

export { module as default };
